```{include} ../README.md
:start-line: 0
:end-line: 5
```

Lookup & curate metadata based on scientific standards.

- Gene: [Ensembl](https://ensembl.org/), [NCBI Gene](https://www.ncbi.nlm.nih.gov/gene/), [HGNC](https://www.genenames.org/), [MGI](http://www.informatics.jax.org/)
- Protein: [Uniprot](https://www.uniprot.org/)
- Species: [NCBI Taxonomy](https://www.ncbi.nlm.nih.gov/taxonomy/), [Ensembl Species](https://useast.ensembl.org/info/about/species.html)
- Cell type: [Cell Ontology](https://obophenotype.github.io/cell-ontology/)
- Cell marker: [CellMarker](http://xteam.xbio.top/CellMarker)
- Tissue: [Uberon](http://obophenotype.github.io/uberon/)
- Disease: [Mondo](https://mondo.monarchinitiative.org/)

Install:

```
pip install bionty
```

Resources:

- Get started with the [guide](guide/index), or browse the [API reference](api) and [FAQ](faq/index).
- See the [source code](https://github.com/laminlabs/bionty) on GitHub.
- See [bionty-assets](https://lamin.ai/docs/bionty-assets) for the curation of underlying assets.
- See the [changelog](changelog) for updates.

```{toctree}
:maxdepth: 1
:hidden:

guide/index
api
faq/index
changelog
```
